==> azure-resourcemanager-network-2.43.0-sources.jar: com/azure/resourcemanager/network/models/DdosProtectionPlans.java <==
// Copyright (c) Microsoft Corporation. All rights reserved.
// Licensed under the MIT License.
package com.azure.resourcemanager.network.models;

import com.azure.core.annotation.Fluent;
import com.azure.resourcemanager.network.NetworkManager;
import com.azure.resourcemanager.resources.fluentcore.arm.collection.SupportsBatchDeletion;
import com.azure.resourcemanager.resources.fluentcore.arm.collection.SupportsDeletingByResourceGroup;
import com.azure.resourcemanager.resources.fluentcore.arm.collection.SupportsGettingById;
import com.azure.resourcemanager.resources.fluentcore.arm.collection.SupportsGettingByResourceGroup;
import com.azure.resourcemanager.resources.fluentcore.arm.collection.SupportsListingByResourceGroup;
import com.azure.resourcemanager.resources.fluentcore.arm.models.HasManager;
import com.azure.resourcemanager.resources.fluentcore.collection.SupportsBatchCreation;
import com.azure.resourcemanager.resources.fluentcore.collection.SupportsCreating;
import com.azure.resourcemanager.resources.fluentcore.collection.SupportsDeletingById;
import com.azure.resourcemanager.resources.fluentcore.collection.SupportsListing;

/** Entry point to DDoS protection plans management. */
@Fluent
public interface DdosProtectionPlans
    extends SupportsCreating<DdosProtectionPlan.DefinitionStages.Blank>,
        SupportsListing<DdosProtectionPlan>,
        SupportsListingByResourceGroup<DdosProtectionPlan>,
        SupportsGettingByResourceGroup<DdosProtectionPlan>,
        SupportsGettingById<DdosProtectionPlan>,
        SupportsDeletingById,
        SupportsDeletingByResourceGroup,
        SupportsBatchCreation<DdosProtectionPlan>,
        SupportsBatchDeletion,
        HasManager<NetworkManager> {
}

==> azure-resourcemanager-network-2.57.0-sources.jar: com/azure/resourcemanager/network/models/DdosProtectionPlans.java <==
// Copyright (c) Microsoft Corporation. All rights reserved.
// Licensed under the MIT License.
package com.azure.resourcemanager.network.models;

import com.azure.core.annotation.Fluent;
import com.azure.resourcemanager.network.NetworkManager;
import com.azure.resourcemanager.resources.fluentcore.arm.collection.SupportsBatchDeletion;
import com.azure.resourcemanager.resources.fluentcore.arm.collection.SupportsDeletingByResourceGroup;
import com.azure.resourcemanager.resources.fluentcore.arm.collection.SupportsGettingById;
import com.azure.resourcemanager.resources.fluentcore.arm.collection.SupportsGettingByResourceGroup;
import com.azure.resourcemanager.resources.fluentcore.arm.collection.SupportsListingByResourceGroup;
import com.azure.resourcemanager.resources.fluentcore.arm.models.HasManager;
import com.azure.resourcemanager.resources.fluentcore.collection.SupportsBatchCreation;
import com.azure.resourcemanager.resources.fluentcore.collection.SupportsCreating;
import com.azure.resourcemanager.resources.fluentcore.collection.SupportsDeletingById;
import com.azure.resourcemanager.resources.fluentcore.collection.SupportsListing;

/** Entry point to DDoS protection plans management. */
@Fluent
public interface DdosProtectionPlans
    extends SupportsCreating<DdosProtectionPlan.DefinitionStages.Blank>, SupportsListing<DdosProtectionPlan>,
    SupportsListingByResourceGroup<DdosProtectionPlan>, SupportsGettingByResourceGroup<DdosProtectionPlan>,
    SupportsGettingById<DdosProtectionPlan>, SupportsDeletingById, SupportsDeletingByResourceGroup,
    SupportsBatchCreation<DdosProtectionPlan>, SupportsBatchDeletion, HasManager<NetworkManager> {
}
